==> tknodesystem-0.6.tar.gz: tknodesystem-0.6/README.md <==
![title](https://github.com/Akascape/TkNodeSystem/assets/89206401/a84cb60a-cc6f-4609-8452-3ff4fcd0c46b)

**Simple Node System (DAG) in tkinter python!**

## Feature
- Lightweight library
- Easy to install and use
- Multiple nodes and inputs
- **Save/Load** node trees
- Canvas with **drag and zoom** ability
- Customizable nodes and options
- Built-in **Node menu**

## Installation
```
pip install tknodesystem
```
### [<img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/Akascape/TkNodeSystem?&color=cyan&label=Download%20Source%20Code&logo=Python&logoColor=yellow&style=for-the-badge"  width="400">](https://github.com/Akascape/TkNodeSystem/archive/refs/heads/main.zip)

[![PyPI](https://img.shields.io/pypi/v/tknodesystem)](https://pypi.org/project/tknodesystem)
[![Downloads](https://static.pepy.tech/badge/tknodesystem)](https://pepy.tech/project/tknodesystem)
![Platform](https://img.shields.io/powershellgallery/p/Pester?color=blue)

### Requirements
- tkinter
- customtkinter _(for the node menu)_

## Overview

- Node Types

![node_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/cccf82dd-8207-4894-9e9e-ef240e511d85)

- Node Menu

![node_menu](https://github.com/Akascape/TkNodeSystem/assets/89206401/0ba5ba42-4787-4b94-8b40-682084df2e80)

- Node Canvas

![canvas_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/d5568962-50c0-404c-bf71-79d66f79e3b7)

## Documentation
Full documentation can be found in the **Wiki** page

[<img src="https://img.shields.io/badge/View-Docs-informational?&color=c8ab09&style=for-the-badge" width="150">](https://github.com/Akascape/TkNodeSystem/wiki)

## Examples
Examples are given in the [`examples`](https://github.com/Akascape/TkNodeSystem/tree/main/examples) folder
![Example App](https://github.com/Akascape/TkNodeSystem/assets/89206401/ea818333-c979-4402-bc7c-8850930dc087)

### Bug Fixes
This library is at **experimental stage**, so there must be some bugs which can appear randomly.

**So, please report the bugs at the issues/discussions tab. A pull request is always welcomed :)**

==> tknodesystem-0.9.tar.gz: tknodesystem-0.9/README.md <==
![title](https://github.com/Akascape/TkNodeSystem/assets/89206401/a84cb60a-cc6f-4609-8452-3ff4fcd0c46b)

**Advanced Node System (DAG) in tkinter python!**

## Feature
- Lightweight library
- Easy to install and use
- Multiple nodes and inputs
- **Save/Load** node trees
- Canvas with **drag and zoom** ability
- Customizable nodes and options
- Built-in **Node menu**

## Installation
```
pip install tknodesystem
```
### [<img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/Akascape/TkNodeSystem?&color=cyan&label=Download%20Source%20Code&logo=Python&logoColor=yellow&style=for-the-badge"  width="400">](https://github.com/Akascape/TkNodeSystem/archive/refs/heads/main.zip)

[![PyPI](https://img.shields.io/pypi/v/tknodesystem)](https://pypi.org/project/tknodesystem)
[![Downloads](https://static.pepy.tech/badge/tknodesystem)](https://pepy.tech/project/tknodesystem)
![Platform](https://img.shields.io/powershellgallery/p/Pester?color=blue)

### Requirements
- tkinter
- customtkinter _(for the node menu)_

## Overview

- Node Types

![node_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/cccf82dd-8207-4894-9e9e-ef240e511d85)

- Node Menu

![node_menu](https://github.com/Akascape/TkNodeSystem/assets/89206401/0ba5ba42-4787-4b94-8b40-682084df2e80)

- Node Canvas

![canvas_types](https://github.com/Akascape/TkNodeSystem/assets/89206401/d5568962-50c0-404c-bf71-79d66f79e3b7)

## Documentation
Full documentation can be found in the **Wiki** page

[<img src="https://img.shields.io/badge/View-Docs-informational?&color=c8ab09&style=for-the-badge" width="150">](https://github.com/Akascape/TkNodeSystem/wiki)

## Examples
Examples can be found in the [`examples`](https://github.com/Akascape/TkNodeSystem/tree/main/examples) folder.

<div align="center">
  
### Level: Beginner
Maths with tknodes

![Example1](https://github.com/Akascape/TkNodeSystem/assets/89206401/9bb709fa-78e8-4db0-b5f1-8848fd32aa81)

### Level: Intermediate
Image manipulation with PIL
  
![Example2](https://github.com/Akascape/TkNodeSystem/assets/89206401/ea818333-c979-4402-bc7c-8850930dc087)

### Level: Advanced
3D Viewer

![Screenshot](https://github.com/Akascape/TkNodeSystem/assets/89206401/83e5d356-947e-4737-9f92-487a2cfc7d3f)
![Screenshot](https://github.com/Akascape/TkNodeSystem/assets/89206401/a5695e72-c739-41ce-a700-20c3b4bd052b)

</div>

### Bug Fixes
This library is at **experimental stage**, so there must be some bugs which can appear randomly.

**So, please report the bugs at the issues/discussions tab. A pull request is always welcomed :)**
